# Dapr 1.8.7

- Fixes component initialization failure when the built-in Kubernetes secret store is disabled
- Fixes nil dereference crash in placement membership heartbeat loop in sidecar

## Fixes component initialization failure when the built-in Kubernetes secret store is disabled

### Problem

When running on Kubernetes, Dapr automatically initializes a Kubernetes secret store in each sidecar. Starting with Dapr 1.8, this behavior can be [turned off](https://docs.dapr.io/reference/arguments-annotations-overview/) using the `dapr.io/disable-builtin-k8s-secret-store`.

However, with the built-in Kubernetes secret store disabled, an error prevented components from being able to retrieve secrets [stored as Kubernetes secrets](https://docs.dapr.io/operations/components/component-secrets/#referencing-a-kubernetes-secret) during initialization. This caused components to fail to initialize due to not being able to read secrets, for example connection strings or passwords.

### Impact

The issue impacts users on Dapr 1.8.0-1.9.4 who want to disable the built-in Kubernetes secret store.

### Root cause

In Dapr, components that use secrets stored as Kubernetes secrets should not need the built-in Kubernetes secret store to be loaded to work. This is because the Dapr Operator service populates the secrets from the Kubernetes secret store and passes them to the sidecar automatically.

However, during initialization of a component that references a secret stored in Kubernetes, a bug caused Dapr to return an error if the built-in Kubernetes secret store was disabled, and the value of the secret as included by the Dapr Operator was ignored.

### Solution

We have implemented a fix in the component initialization sequence. Now, components that reference secrets from the Kubernetes secret store do not need the built-in Kubernetes secret store to be enabled anymore.


## Fixes panic in actor placement membership in Dapr sidecar

### Problem

When recovering from a failure in the connection to the Dapr placement service, the Dapr sidecar could have encountered a panic in some cases.

### Impact

The issue can impact all Dapr users on Dapr 1.7.0-1.9.4 using actors.

### Root cause

We identified a race condition in the actor placement service client that could have caused the Dapr to panic after recovering from a failure.

### Solution

We updated actor placement service to address the race condition and remove the cause for the panic.